==> klearnnotes2-1.0-2.tar.gz: klearnnotes2-1.0/src/midi.h <==
/***************************************************************************
 ** $Id: midi.h,v 1.2 2003/10/13 09:38:23 marek Exp $
                          klearnnotes2
                          midi.h -  description
                             -------------------
    begin                : Wed Oct  8 15:32:54 CEST 2003
    copyright            : (C) 2003 by Marek Wieckowski
    email                : wiecko AT users.sourceforge.net
***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

// SOUND

#include <stdlib.h>   //-
#include <stdio.h>    //-
#include <unistd.h>   //-
#include <fcntl.h>    //-
#include <stdarg.h>
#include <sys/types.h>

#include <sys/ioctl.h>      // for writing to the device 
#include <sys/soundcard.h>  // the soundcard macro definitions 

#define MIDI_DEV "/dev/sequencer"
#define defMIDIdevNum 0        // initial device number 
#define defMIDIchan 16         // initial no of MIDI channels 
//#define defMIDIvol 100         // volume

// SOUND functions
void midi_addANote2chord(int note); // for polyphony: you first add notes ...
void midi_playChord(); // ... and then play whole chord
void midi_setupPatches();
bool midi_turnOn();
void midi_turnOff();
bool midiIsOn();

extern int midiMaxChan;// max no of channels
extern int midiCurrentChannel;
extern int midiCurrentDevice;
//extern int midiCurrentVolume;
extern int midiNoteLength;
extern int midiPatch;

==> klearnnotes2-1.1.tar.gz: klearnnotes2-1.1/src/midi.h <==
/***************************************************************************
 ** $Id: midi.h,v 1.2 2003/10/20 04:08:44 wiecko Exp $
                          klearnnotes2
                          midi.h -  description
                             -------------------
    begin                : Wed Oct  8 15:32:54 CEST 2003
    copyright            : (C) 2003 by Marek Wieckowski
    email                : wiecko AT users.sourceforge.net
***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

// SOUND

#include <stdlib.h>   //-
#include <stdio.h>    //-
#include <unistd.h>   //-
#include <fcntl.h>    //-
#include <stdarg.h>
#include <sys/types.h>

#include <sys/ioctl.h>      // for writing to the device 
#include <sys/soundcard.h>  // the soundcard macro definitions 

#define MIDI_DEV "/dev/sequencer"
#define defMIDIdevNum 0        // initial device number 
#define defMIDIchan 16         // initial no of MIDI channels 
#define defMASTERvol 100       // master volume
#define defMIDIvol 100         // midi volume

// SOUND functions
void midi_addANote2chord(int note); // for polyphony: you first add notes ...
void midi_playChord(); // ... and then play whole chord
void midi_setupPatches();
bool midi_turnOn();
void midi_turnOff();
bool midiIsOn();
bool mixerIsOpen();
void mixerSetMasterVolume(int newvol);
void mixerSetMidiVolume(int newvol);
int  mixerMasterVolume();
int  mixerMidiVolume();


extern int midiMaxChan;// max no of channels
extern int midiCurrentChannel;
extern int midiCurrentDevice;
extern int midiCurrentMaterVoulume;
extern int midiCurrentVolume;
extern int midiNoteLength;
extern int midiPatch;
